<?php
	use PFAdviceServer\authentication;

require_once '../../include/PFAdviceServer/ComposerAdvicePortafirmas.php';


	// Cliente modificado para hacer pruebas
	class SoapClientDebug extends SoapClient
	{
		private $debugMode = false;

		public function __construct($wsdl, $options = array(), $debugMode = false) {
			$this->debugMode = $debugMode;
			parent::__construct($wsdl, $options);
		}

		public function __doRequest($request, $location, $action, $version, $one_way = 0) {
			$request = str_replace('xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"', '', $request);

			if ($this->debugMode) {
				$doc = new DomDocument('1.0');
				$doc->preserveWhiteSpace = false;
				$doc->formatOutput = true;
				$doc->loadXML($request);
				$xml_string = $doc->saveXML();
				echo "$xml_string\n";

				return "";
			} else {
				return parent::__doRequest($request, $location, $action, $version);
			}

		}
	}

	// Clase auxiliar para generar pruebas
	class PFHelper {
		protected static $NAMESPACE_PF = null;	// 'urn:juntadeandalucia:cice:pfirma:type:v2.0';

		private function pf_doAuth($username, $password, $fieldName, $ns) {
			$oAux = new PFAdviceServer\authentication();
			$oAux->setUserName($username);
			$oAux->setPassword($password);
			$authWS = $oAux->toSoap($fieldName, $ns);

			$mainWS = new ArrayObject();
			$mainWS->append(new SoapVar($authWS, SOAP_ENC_OBJECT,null,null, $fieldName, $ns));
			return $mainWS;
		}

		public function pf_prepare($username, $password, $request, $signature)
		{
			// Nivel de peticion
			$mainWS = $this->pf_doAuth($username, $password, 'authentication', self::$NAMESPACE_PF);
			$mainWS->append($request->toSoap('request', self::$NAMESPACE_PF));
			//$mainWS->append($request->toSoap('request', self::$NAMESPACE_PF));

			return $mainWS;
		}//pf_prepare

		public function pf_prepareArray($username, $password, $request, $signature)	{
			$fieldName = 'authentication';
			$ns = self::$NAMESPACE_PF;

			$oAux = new authentication();
			$oAux->setUserName($username);
			$oAux->setPassword($password);
			$authWS = $oAux->toSoap($fieldName, $ns);

			$vData = array();
			$vData[] = new SoapVar($authWS, SOAP_ENC_OBJECT,null,null, $fieldName, $ns);
			$vData[] = $request->toSoap('request', self::$NAMESPACE_PF);
			//$mainWS->append($request->toSoap('request', self::$NAMESPACE_PF));

			return $vData;
		}//pf_prepare

		public function createTestRequest() {
			// pf_mod_createRequest
			$request = new PFAdviceServer\request();
			$request->setSubject("Prueba");
			$request->setFentry(new DateTime());
			$request->setFstart(new DateTime());
			$request->setFexpiration((new DateTime())->modify('1 day'));
			$request->setReference('Referencia Opcional');
			$request->setText('contenido del mensaje');
			$request->setSignType('CASCADA');
			$request->setApplication('WSCOMUN');

			$impLvl = new PFAdviceServer\importanceLevel();
			$impLvl->setLevelCode(2);
			$impLvl->setDescription('Alta');
			$request->setImportanceLevel($impLvl);

			$docType = new PFAdviceServer\documentType();
			$docType->setIdentifier('INFORME');
			$docType->setDescription('Informe generico');
			$docType->setValid(true);

			/*
			 $doc = new document();
			 $doc->setIdentifier('12345678');
			 $doc->setName('documento de prueba.pdf');
			 $doc->setMime('application/pdf');
			 $doc->setDocumentType($docType);
			 $doc->setContent('content');	// BASE64
			 //$doc->setType($value);
			 //$doc->setUri($value);
			 $doc->setSign(true);

			 $docList = new documentList();
			 $docList->addDocument($doc);

			 $request->setDocumentList($docList);
			 */

			$signerUserJob = new PFAdviceServer\user();
			$signerUserJob->setIdentifier('WSCOMUN');
			$signer = new PFAdviceServer\signer();
			$signer->setUserJob($signerUserJob);

			$signerUserJob2 = new PFAdviceServer\job();
			$signerUserJob2->setIdentifier('CARGO 1 PRUEBAS WSCOMUN');
			$signer2 = new PFAdviceServer\signer();
			$signer2->setUserJob($signerUserJob2);

			$signerList = new PFAdviceServer\signerList();
			$signerList->addSigner($signer);
			$signerList->addSigner($signer2);
			$signLine = new PFAdviceServer\signLine();
			$signLine->setSignerList($signerList);
			$signLine->setType('FIRMA');
			$signLineList = new PFAdviceServer\signLineList();
			$signLineList->addSignLine($signLine);
			$request->setSignLineList($signLineList);

			$userRemitter = new PFAdviceServer\user();
			$userRemitter->setIdentifier('WSCOMUN');
			$remitterList = new PFAdviceServer\remitterList();
			$remitterList->addUser($userRemitter);
			$request->setRemitterList($remitterList);

			//$request->setParameterList($value);
			//$request->setNoticeList($value);
			//$request->setActionList($value);
			//$request->setCommentList($value);
			$request->setRequestStatus('EN PROCESO');

			return $request;
		}	// f_createTestRequest
	}



	// Configuracion PHP-SOAP
	ini_set('soap.wsdl_cache_enabled',0);
	//ini_set('soap.wsdl_cache_ttl',0);
	set_time_limit(300);

	// Especificamos el wsdl que utilizaremos en nuestro servicio web.
	$wsdl = 'http://localhost/wscomun_BUENO/PF_Advice/server.php?wsdl';

	$opcionesClienteWS = array (
			'soap_version' => SOAP_1_1, //SOAP 1.2
			'exceptions' => true,
			'cache_wsdl' => WSDL_CACHE_BOTH,
			'trace' => true
	);

	// Instanciamos un cliente nativo de la clase de PHP con el $wsdl especificado anteriormente.
	$client = new SoapClientDebug($wsdl, $opcionesClienteWS, false);


	// Crea una peticion de pruebas
	$pfhelper = new PFHelper();
	$request = $pfhelper->createTestRequest();


	// Realiza la llamada al servidor
	try {
		$mainWS = $pfhelper->pf_prepare('username1', 'password1', $request, array());
		$miSoapRQ = new SoapVar($mainWS, SOAP_ENC_OBJECT,null,null, 'updateRequestStatus', null);
		$respuestaUpdate = $client->updateRequestStatus($miSoapRQ);

		//$vRequest = $pfhelper->pf_prepareArray('user', 'password', $request, array());
		//$respuestaUpdate = $client->__soapCall('updateRequestStatus', $vRequest);

		print_r($respuestaUpdate);

	} catch (\SoapFault $soapFault) {
		print("<pre>SoapFault: \n");
		print_r($soapFault);
		print_r($client);
		//print_r($miSoapRQ);
		//var_dump($vRequest);
	} catch (\Exception $e) {
		print("<pre>Exception: \n");
		print_r($e);
		print_r($client);
		//print_r($miSoapRQ);
		//var_dump($vRequest);
	}


?>